/**
 * @file i2c_slave.c
 * I2C slave mode driver
 *    
 * @author Roland Michael dela Pea
 * @date 06-29-2012
 *
 */

#include <htc.h>
#include "i2c_slave.h"
#include "delay.h"

const	unsigned char mask = 0x25;		//I2C states mask

void i2c_slave_initialize() {
	TRIS_SDA = 1;			// SDA input
	TRIS_SCL = 1;			// SCL input

	SSPBUF  = 0x0;
	SSPSTAT = 0x80;				  // 100Khz
	SSPADD = SLAVE_ADDR;	
	SSPCON = 0x36;				  // Slave mode, 7bit addr	
	SSPCON3 |= 0b01100000;  // enable start and stop conditions
}

void _write_data(unsigned char data) {
	do {
		WCOL=0;
		SSPBUF = data;
	} while(WCOL);
	CKP = 1;
}

int process_i2c_tasks() {
	unsigned char temp;
	unsigned char token = 0;	
	
	if (SSP1IF) {
		token  = SSPSTAT & mask;	//obtain current state
		if (S) {	
			switch (token) {
				case MWA: //MASTER WRITES ADDRESS STATE
					temp = SSPBUF;
					master_status = I2C_SLAVE_ADDRESS_RECEIVED;
				break;
					
				case MWD: //MASTER WRITES DATA STATE
					temp = SSPBUF;
					if (master_status == I2C_SLAVE_ADDRESS_RECEIVED) {
						// first time we get the slave address, after that set to word address
						master_mode = temp;
						master_index = 0;
						master_status = I2C_MODE_RECEIVED;
					}
					else if (master_status == I2C_MODE_RECEIVED) {
						// second time we get the mode, so look into mode
						if (master_mode == MODE_WRITE_EEPROM) {
							++master_index;
							if (master_index == 1) {
								// We've got the EEPROM address
								eeprom_addr = temp;
							}
							else if (master_index == 2) {
								// We've got the assigned EEPROM value
								eeprom_val = temp;
								master_cmd = EXECUTE_WRITE_EEPROM;
							}
							else if (master_index > 2) {
								master_cmd = EXECUTE_NONE;
							}
						}
						else if (master_mode == MODE_READ_EEPROM) {
							// We've got the EEPROM address
							eeprom_addr = temp;
							master_cmd = EXECUTE_READ_EEPROM;
						}
						else if (master_mode == MODE_RESET) {
							master_cmd = EXECUTE_RESET;
						}
					}
				break;
				
				case MRA: //MASTER READS ADDRESS STATE
					temp = SSPBUF;
					if (master_cmd == EXECUTE_READ_EEPROM) {
						_write_data(eeprom_read(eeprom_addr));
					}
					break;				
				
				case MRD: //MASTER READS DATA STATE

					break;		
			}
		}
		else if (P) { //STOP state	
			asm("nop");
			if (master_cmd == EXECUTE_WRITE_EEPROM) {
				eeprom_write(eeprom_addr, eeprom_val);
			}
			else if (master_cmd == EXECUTE_RESET) {
				DelayMs(5);
				#asm
					RESET;
				#endasm
			}
			master_status = I2C_NO_TRANSACTION; 
		}
		SSP1IF = 0;
		SSPEN = 1;														
		CKP = 1;	//release clock
	}
}