/**
 * @file i2c_slave.h
 * I2C slave mode driver
 *    
 * @author Roland Michael dela Pea
 * @date 06-29-2012
 *
 */

#include "typedef.h"

#define TRIS_SDA TRISC1
#define TRIS_SCL TRISC0

// Serial communication states
#define I2C_NO_TRANSACTION					0
#define I2C_SLAVE_ADDRESS_RECEIVED			1
#define I2C_MODE_RECEIVED					2
#define I2C_READ_ADDRESS					3
#define I2C_READ_DATA						4
#define I2C_MASTER_NACK						5

#define MODE_WRITE_EEPROM 0xaa
#define MODE_READ_EEPROM 0xab
#define MODE_RESET 0xac

// DSADS01 defined execute command
#define EXECUTE_NONE 0xa0
#define EXECUTE_WRITE_EEPROM 0xa1
#define EXECUTE_READ_EEPROM 0xa2
#define EXECUTE_RESET 0xa3

// slave address definition
#define SLAVE_ADDR 0xa0

// define states
#define MWA 0x1			//Master Writes Address
#define MWD 0x21		//Master Writes Data
#define MRA 0x5			//Master Reads Address
#define MRD 0x24		//Master Reads Data

// function prototypes
void i2c_slave_initialize(void);
int process_i2c_tasks(void);

extern unsigned char master_index;
extern unsigned char master_mode;
extern unsigned char master_status;
extern unsigned char master_cmd;
extern unsigned char eeprom_addr;
extern unsigned char eeprom_val;

